{"java/lang/Runtime", "exitInternal", "(I)V", (void*) Java_java_lang_Runtime_exitInternal }, 
{"java/lang/Runtime", "gc", "()V", (void*) Java_java_lang_Runtime_gc }, 
{"java/lang/Runtime", "runFinalization", "()V", (void*) Java_java_lang_Runtime_runFinalization }, 
{"java/lang/Runtime", "runFinalizersOnExitInternal", "(Z)V", (void*) Java_java_lang_Runtime_runFinalizersOnExitInternal }, 
{"java/lang/Runtime", "freeMemory", "()J", (void*) Java_java_lang_Runtime_freeMemory }, 
{"java/lang/Runtime", "totalMemory", "()J", (void*) Java_java_lang_Runtime_totalMemory }, 
{"java/lang/Runtime", "traceInstructions", "(Z)V", (void*) Java_java_lang_Runtime_traceInstructions }, 
{"java/lang/Runtime", "traceMethodCalls", "(Z)V", (void*) Java_java_lang_Runtime_traceMethodCalls }, 
{"java/lang/Runtime", "nativeLoad", "(Ljava/lang/String;)I", (void*) Java_java_lang_Runtime_nativeLoad }, 
{"java/lang/Runtime", "nativeGetLibname", "(Ljava/lang/String;Ljava/lang/String;)Ljava/lang/String;", (void*) Java_java_lang_Runtime_nativeGetLibname }, 
{"java/lang/Runtime", "execInternal", "([Ljava/lang/String;[Ljava/lang/String;)Ljava/lang/Process;", (void*) Java_java_lang_Runtime_execInternal }, 
{"java/lang/Runtime", "getLibraryPath", "()Ljava/lang/String;", (void*) Java_java_lang_Runtime_getLibraryPath },
